@@ -26,6 +26,7 @@ def cli(info, info_line_numbers):
 @click.option("--should-collect-cloudformation-events", default=None, type=bool)
 @click.option("--should-forward-events-to-eventbridge", default=None, type=bool)
 @click.option("--should-forward-failures-to-opscenter", default=None, type=bool)
+@click.option("--on-complete-url", default=None)
 def deploy(
     f,
     single_account,
@@ -37,6 +38,7 @@ def deploy(
     should_collect_cloudformation_events,
     should_forward_events_to_eventbridge,
     should_forward_failures_to_opscenter,
+    on_complete_url,
 ):
     if puppet_account_id is None:
         puppet_account_id = config.get_puppet_account_id()
@@ -64,6 +66,7 @@ def deploy(
         single_account=single_account,
         num_workers=num_workers,
         execution_mode=execution_mode,
+        on_complete_url=on_complete_url,
     )
 
 
